@@ -1,6 +1,8 @@
 #![feature(array_from_fn)]
 
 pub mod error;
+#[cfg(feature = "extra")]
+pub mod extra;
 
 mod primitives;
 
